Index: wp-includes/locale.php
===================================================================
--- wp-includes/locale.php	(revision 13330)
+++ wp-includes/locale.php	(working copy)
@@ -178,14 +178,6 @@
 		// Numbers formatting
 		// See http://php.net/number_format
 
-		/* translators: $decimals argument for http://php.net/number_format, default is 0 */
-		$trans = __('number_format_decimals');
-		$this->number_format['decimals'] = ('number_format_decimals' == $trans) ? 0 : $trans;
-
-		/* translators: $dec_point argument for http://php.net/number_format, default is . */
-		$trans = __('number_format_decimal_point');
-		$this->number_format['decimal_point'] = ('number_format_decimal_point' == $trans) ? '.' : $trans;
-
 		/* translators: $thousands_sep argument for http://php.net/number_format, default is , */
 		$trans = __('number_format_thousands_sep');
 		$this->number_format['thousands_sep'] = ('number_format_thousands_sep' == $trans) ? ',' : $trans;
Index: wp-admin/admin-header.php
===================================================================
--- wp-admin/admin-header.php	(revision 13330)
+++ wp-admin/admin-header.php	(working copy)
@@ -35,7 +35,7 @@
 //<![CDATA[
 addLoadEvent = function(func){if(typeof jQuery!="undefined")jQuery(document).ready(func);else if(typeof wpOnload!='function'){wpOnload=func;}else{var oldonload=wpOnload;wpOnload=function(){oldonload();func();}}};
 var userSettings = {'url':'<?php echo SITECOOKIEPATH; ?>','uid':'<?php if ( ! isset($current_user) ) $current_user = wp_get_current_user(); echo $current_user->ID; ?>','time':'<?php echo time() ?>'};
-var ajaxurl = '<?php echo admin_url('admin-ajax.php'); ?>', pagenow = '<?php echo substr($pagenow, 0, -4); ?>', typenow = '<?php echo $typenow; ?>', adminpage = '<?php echo $admin_body_class; ?>',  thousandsSeparator = '<?php echo addslashes( $wp_locale->number_format['thousands_sep'] ); ?>', decimalPoint = '<?php echo addslashes( $wp_locale->number_format['decimal_point'] ); ?>';
+var ajaxurl = '<?php echo admin_url('admin-ajax.php'); ?>', pagenow = '<?php echo substr($pagenow, 0, -4); ?>', typenow = '<?php echo $typenow; ?>', adminpage = '<?php echo $admin_body_class; ?>',  thousandsSeparator = '<?php echo addslashes( $wp_locale->number_format['thousands_sep'] ); ?>';
 //]]>
 </script>
 <?php
Index: wp-includes/load.php
===================================================================
--- wp-includes/load.php	(revision 13330)
+++ wp-includes/load.php	(working copy)
@@ -215,7 +215,7 @@
 	$mtime = $mtime[1] + $mtime[0];
 	$timeend = $mtime;
 	$timetotal = $timeend-$timestart;
-	$r = ( function_exists( 'number_format_i18n' ) ) ? number_format_i18n( $timetotal, $precision ) : number_format( $timetotal, $precision );
+	$r = number_format( $timetotal, $precision );
 	if ( $display )
 		echo $r;
 	return $r;

Index: wp-includes/functions.php
===================================================================
--- wp-includes/functions.php	(revision 13330)
+++ wp-includes/functions.php	(working copy)
@@ -126,23 +126,20 @@
 }
 
 /**
- * Convert number to format based on the locale.
+ * Convert integer number to format based on the locale.
  *
  * @since 2.3.0
  *
- * @param mixed $number The number to convert based on locale.
- * @param int $decimals Precision of the number of decimal places.
+ * @param int $number The number to convert based on locale.
+ * @param int $decimals Precision of the number of decimal places. Deprectated.
  * @return string Converted number in string format.
  */
 function number_format_i18n( $number, $decimals = null ) {
 	global $wp_locale;
-	// let the user override the precision only
-	$decimals = ( is_null( $decimals ) ) ? $wp_locale->number_format['decimals'] : intval( $decimals );
-
-	$num = number_format( $number, $decimals, $wp_locale->number_format['decimal_point'], $wp_locale->number_format['thousands_sep'] );
-
-	// let the user translate digits from latin to localized language
-	return apply_filters( 'number_format_i18n', $num );
+	$number = (int)$number;
+	if ( !is_null( $decimals ) ) _deprecated_argument( __FUNCTION__, '3.0' );
+	$formatted = number_format( $number, 0, null, $wp_locale->number_format['thousands_sep'] );
+	return apply_filters( 'number_format_i18n', $formatted );
 }
 
 /**
@@ -163,10 +160,10 @@
  * @since 2.3.0
  *
  * @param int|string $bytes Number of bytes. Note max integer size for integers.
  * @param int $decimals Precision of number of decimal places.
  * @return bool|string False on failure. Number string on success.
  */
-function size_format( $bytes, $decimals = null ) {
+function size_format( $bytes ) {
 	$quant = array(
 		// ========================= Origin ====
 		'TB' => 1099511627776,  // pow( 1024, 4)
@@ -175,10 +172,10 @@
 		'kB' => 1024,           // pow( 1024, 1)
 		'B ' => 1,              // pow( 1024, 0)
 	);
-
+	if ( !is_null( $decimals ) ) _deprecated_argument( __FUNCTION__, '3.0' );
 	foreach ( $quant as $unit => $mag )
 		if ( doubleval($bytes) >= $mag )
-			return number_format_i18n( $bytes / $mag, $decimals ) . ' ' . $unit;
+			return number_format_i18n( round( $bytes / $mag ) ) . ' ' . $unit;
 
 	return false;
 }
@@ -163,10 +160,10 @@
  *
  * @param int|string $bytes Number of bytes. Note max integer size for integers.
- * @param int $decimals Precision of number of decimal places.
+ * @param int $decimals Precision of number of decimal places. Deprecated.
  * @return bool|string False on failure. Number string on success.
  */